@@ -1,5 +1,5 @@
 #  This file is part of OctoBot (https://github.com/Drakkar-Software/OctoBot)
-#  Copyright (c) 2022 Drakkar-Software, All rights reserved.
+#  Copyright (c) 2023 Drakkar-Software, All rights reserved.
 #
 #  OctoBot is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -73,15 +73,6 @@ def update_config_with_args(starting_args, config: configuration.Configuration,
         config.config[common_constants.CONFIG_TRADING][common_constants.CONFIG_TRADER_RISK] = starting_args.risk
 
 
-# def _check_public_announcements(logger):
-#     try:
-#         announcement = get_external_resource(EXTERNAL_RESOURCE_PUBLIC_ANNOUNCEMENTS)
-#         if announcement:
-#             logger.info(announcement)
-#     except Exception as e:
-#         logger.warning("Impossible to check announcements: {0}".format(e))
-
-
 def _log_terms_if_unaccepted(config: configuration.Configuration, logger):
     if not config.accepted_terms():
         logger.info("*** Disclaimer ***")
@@ -127,7 +118,7 @@ def _create_startup_config(logger):
     else:
         _read_config(config, logger)
         try:
-            _ensure_profile(config)
+            commands.ensure_profile(config)
             _validate_config(config, logger)
         except (errors.NoProfileError, errors.ConfigError):
             # real issue if tentacles exist otherwise continue
@@ -136,16 +127,6 @@ def _create_startup_config(logger):
     return config, is_first_startup
 
 
-def _download_and_select_profile(logger, config, to_download_profile_urls, to_select_profile):
-    if to_download_profile_urls:
-        commands.download_missing_env_profiles(
-            config,
-            to_download_profile_urls
-        )
-    if commands.select_forced_profile_if_any(config, to_select_profile, logger):
-        _ensure_profile(config)
-
-
 async def _apply_community_startup_info_to_config(logger, config, community_auth):
     try:
         if not community_auth.is_initialized() and constants.USER_ACCOUNT_EMAIL and constants.USER_PASSWORD_TOKEN:
@@ -158,7 +139,7 @@ async def _apply_community_startup_info_to_config(logger, config, community_auth
             return
         startup_info = await community_auth.get_startup_info()
         logger.debug(f"Fetched startup info: {startup_info}")
-        _download_and_select_profile(
+        commands.download_and_select_profile(
             logger, config,
             startup_info.get_subscribed_products_urls(),
             startup_info.get_forced_profile_url()
@@ -172,7 +153,7 @@ async def _apply_community_startup_info_to_config(logger, config, community_auth
 
 
 def _apply_env_variables_to_config(logger, config):
-    _download_and_select_profile(
+    commands.download_and_select_profile(
         logger, config,
         [url.strip() for url in constants.TO_DOWNLOAD_PROFILES.split(",")] if constants.TO_DOWNLOAD_PROFILES else [],
         constants.FORCED_PROFILE
@@ -204,15 +185,6 @@ def _read_config(config, logger):
         raise errors.ConfigError(e)
 
 
-def _ensure_profile(config):
-    if config.profile is None:
-        # no selected profile or profile not found
-        try:
-            config.select_profile(common_constants.DEFAULT_PROFILE)
-        except KeyError:
-            raise errors.NoProfileError
-
-
 def _validate_config(config, logger):
     try:
         config.validate()
@@ -279,15 +251,15 @@ def start_octobot(args):
         # add args to config
         update_config_with_args(args, config, logger)
 
-        # patch setup with forced values
-        community_auth = _handle_forced_startup_config(logger, config, is_first_startup)
-
         # show terms
         _log_terms_if_unaccepted(config, logger)
 
         # tries to load, install or repair tentacles
         _load_or_create_tentacles(config, logger)
 
+        # patch setup with forced values
+        community_auth = _handle_forced_startup_config(logger, config, is_first_startup)
+
         # Can now perform config health check (some checks require a loaded profile)
         configuration_manager.config_health_check(config, args.backtesting)
 
